@@ -21,7 +21,7 @@ logger = logging.getLogger(__name__)
 
 
 @splunk_appinspect.cert_version(min="1.5.0")
-@splunk_appinspect.tags("splunk_appinspect", "cloud")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
 def check_authorize_conf_capability_not_modified(app, reporter):
     """Check that authorize.conf does not contain any modified capabilities."""
     if app.file_exists("default", "authorize.conf"):
