@@ -46,7 +46,7 @@ def app_package_extractable(check):
 # ORIGIN ARTIFACT CHECKS
 # ------------------------------------------------------------------------------
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service"
+    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service", "private_app"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 @app_package_extractable
@@ -64,7 +64,7 @@ def check_that_splunk_app_package_has_read_permission(app, reporter):
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service"
+    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service", "private_app"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_that_splunk_app_package_valid_compressed_file(app, reporter):
@@ -80,7 +80,7 @@ def check_that_splunk_app_package_valid_compressed_file(app, reporter):
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service"
+    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service", "private_app"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_that_splunk_app_package_name_does_not_start_with_period(app, reporter):
@@ -107,7 +107,7 @@ def check_that_splunk_app_package_name_does_not_start_with_period(app, reporter)
 # WORKING ARTIFACT CHECKS
 # ------------------------------------------------------------------------------
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service"
+    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service", "private_app"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_that_splunk_app_package_extracts_to_visible_directory(app, reporter):
@@ -125,7 +125,7 @@ def check_that_splunk_app_package_extracts_to_visible_directory(app, reporter):
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service"
+    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service", "private_app"
 )
 @splunk_appinspect.cert_version(min="1.5.3")
 @app_package_extractable
@@ -169,7 +169,7 @@ def check_that_splunk_app_package_does_not_contain_files_outside_of_app(app, rep
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service"
+    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service", "private_app"
 )
 @splunk_appinspect.cert_version(min="1.5.3")
 @app_package_extractable
@@ -219,7 +219,7 @@ def check_that_splunk_app_package_with_static_dependencies_has_exactly_one_app_f
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service"
+    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service", "private_app"
 )
 @splunk_appinspect.cert_version(min="1.5.3")
 @app_package_extractable
@@ -253,7 +253,7 @@ def check_that_splunk_app_package_with_static_dependencies_has_app_manifest(
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service"
+    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service", "private_app"
 )
 @splunk_appinspect.cert_version(min="1.5.3")
 @app_package_extractable
@@ -306,7 +306,7 @@ def check_that_splunk_app_package_has_valid_static_dependencies(app, reporter):
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service"
+    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service", "private_app"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 @app_package_extractable
@@ -330,7 +330,7 @@ def check_that_extracted_splunk_app_does_not_contain_prohibited_directories_or_f
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service"
+    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service", "private_app"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_that_extracted_splunk_app_contains_default_app_conf_file(app, reporter):
@@ -347,7 +347,7 @@ def check_that_extracted_splunk_app_contains_default_app_conf_file(app, reporter
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service"
+    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service", "private_app"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_that_extracted_splunk_app_contains_default_app_conf_file_with_valid_version_number(
@@ -398,7 +398,7 @@ def check_that_extracted_splunk_app_contains_default_app_conf_file_with_valid_ve
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service"
+    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service", "private_app"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 @app_package_extractable
@@ -419,7 +419,7 @@ def check_that_extracted_splunk_app_does_not_contain_invalid_directories(app, re
 
 
 @splunk_appinspect.tags(
-    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service"
+    "splunk_appinspect", "appapproval", "cloud", "packaging_standards", "self-service", "private_app"
 )
 @splunk_appinspect.cert_version(min="1.5.0")
 @app_package_extractable
@@ -440,7 +440,7 @@ def check_that_extracted_splunk_app_does_not_contain_files_with_invalid_permissi
         reporter.fail(reporter_output)
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "packaging_standards")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "packaging_standards", "private_app")
 @splunk_appinspect.cert_version(min="1.0.0")
 def check_requires_adobe_flash(app, reporter):
     """Check that the app does not use Adobe Flash files."""
